from noteread.legado.shelf.base import BookSource, BookSourceCorrect
from noteread.legado.shelf.libs.core import load_from_url
from noteread.legado.shelf.libs.correct import correct_source
from noteread.legado.shelf.libs.mumuceo import (RSS_YUAN, SHU_YUAN,
                                                load_from_mumuceo)

urls = [
    "https://cdn.jsdelivr.net/gh/bushixuanqi/book-source/%E4%B9%A6%E6%BA%90%E5%90%88%E9%9B%86.json",

    "https://guaner001125.coding.net/p/coding-code-guide/d/booksources/git/raw/master/sources/guaner.json",
    "https://haxc.coding.net/p/booksrc/d/booksrc/git/raw/master/Book3.0Source.json",

    "https://namofree.gitee.io/yuedu3/legado3_booksource_by_Namo.json",
    "https://pbpobing.coding.net/p/yueduyuan/d/sy/git/raw/master/syhj.json",
    "https://pbpobing.coding.net/p/yueduyuan/d/sy/git/raw/master/yshj.json",

    "http://shuyuan.miaogongzi.net/shuyuan/1624832786.json",
    "https://shuyuan.miaogongzi.net/shuyuan/1630342495.json",
    "http://shuyuan.miaogongzi.net/shuyuan/1623355431.json",

    "https://tangguochaotian.coding.net/p/tangguoshuyuan1015/d/tangguo/git/raw/master/exportBookSource.json",
    "https://tianyuzhange.coding.net/p/booksource/d/shuyuan/git/raw/master/2.0shuyuan.json",
]

book = BookSource(lanzou_fid=4147049)
book_correct = BookSourceCorrect(lanzou_fid=4147049)

# load
load_from_url(cate1='1', urls=urls, book=book)
load_from_mumuceo(cate1='1', source=SHU_YUAN, book=book)
load_from_mumuceo(cate1='2', source=RSS_YUAN, book=book)

# correct
correct_source(book, book_correct)

# print
print(len(book.select_all()))
print(len(book_correct.select_all()))

# save
print(book.db_save())



import json

import requests
from bs4 import BeautifulSoup
from noteread.legado.shelf.base import BookSource
from tqdm import tqdm

APPS = ["yuedu", "yiciyuan", "haikuo"]

SHU_YUAN = "shuyuan"
RSS_YUAN = "rssyuan"
TU_YUAN = "tuyuan"
YING_SHI = "yingshi"
SHI_JIE = "shijie"


def _mumuceo_post(url, data):
    cookies = {
        'PHPSESSID': 'kpdm15hmllfncivlvvqi1e4kq8',
        'Hm_lvt_cd7f08c81646ae0a1ee6c3d93b9956d5': '1631932124,1631959496,1633659120',
        'Hm_lpvt_cd7f08c81646ae0a1ee6c3d93b9956d5': '1633683013',
    }

    headers = {
        'Connection': 'keep-alive',
        'Accept': 'application/json, text/javascript, */*; q=0.01',
        'X-Requested-With': 'XMLHttpRequest',
        'User-Agent': 'Mozilla/5.0 (Linux; Android 6.0; Nexus 5 Build/MRA58N) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/94.0.4606.61 Mobile Safari/537.36',
        'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8',
        'Origin': 'http://yck.mumuceo.com',
        'Referer': 'http://yck.mumuceo.com/yuedu/rssyuan/index.html',
        'Accept-Language': 'zh-CN,zh;q=0.9',
    }
    response = requests.post(url, headers=headers, cookies=cookies, data=data, verify=False)
    return response


def _mumuceo_data_list(app=APPS[0], source=SHU_YUAN, page=1, limit=100):
    data = {
        'page': page,
        'limit': limit
    }
    response = _mumuceo_post(url=f'http://yck.mumuceo.com/{app}/{source}/index.html', data=data)
    df = json.loads(response.text)
    return df


def _mumuceo_detail(app=APPS[0], source=SHU_YUAN, _id='10'):
    params = {
        'id': _id
    }
    response = _mumuceo_post(f'http://yck.mumuceo.com/{app}/{source}/yuan.html', data=params)

    soup = BeautifulSoup(response.text, features="lxml")
    res = soup.find_all(class_='layui-code')
    if len(res) > 0:
        return json.loads(res[0].text)
    else:
        return {}


def load_from_mumuceo(app=APPS[0],
                      source=SHU_YUAN,
                      page=100,
                      cate1='1',
                      book: BookSource = None):
    for _page in tqdm(range(1, 100)):
        df = _mumuceo_data_list(app=app, source=source, page=_page, limit=page)
        size = len(df['data'])
        if size == 0:
            break
        for d in df['data']:
            try:
                d2 = _mumuceo_detail(app=app, source=source, _id=d['id'])
                d2 = json.dumps(d2)
                book.add_json(d2, cate1=cate1)
            except Exception as e:
                print(e)
